@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2005 the xine-project
+ * Copyright (C) 2003-2006 the xine-project
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,13 +16,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: drag_drop.h,v 1.4 2006-02-21 19:06:11 dsalt Exp $
- *
  * drag and drop support functions
  */
 
-#ifndef HAVE_DRAG_DROP_H
-#define HAVE_DRAG_DROP_H
+#ifndef GXINE_DRAG_DROP_H
+#define GXINE_DRAG_DROP_H
 
 typedef struct {
   GtkTreeModel *model;
