@@ -79,7 +79,7 @@ show_about (JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
     GtkBox *vbox;
     /* translators' names go here */
     const gchar *translator = _("TRANSLATOR");
-    gchar *licence = 
+    gchar *licence =
 	_("This program is free software; you can redistribute it and/or "
 	  "modify it under the terms of the GNU General Public Licence as "
 	  "published by the Free Software Foundation; either version 2 of the "
@@ -103,7 +103,7 @@ show_about (JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
 		  "comments", _("A GTK media player front end for xine-lib"),
 		  "license", licence,
 		  "wrap-license", TRUE,
-		  "website", "http://xinehq.de/",
+		  "website", "http://www.xine-project.org/",
 		  "authors", authors,
 		  "documenters", documenters,
 		  "translator-credits",
