@@ -15,13 +15,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: engine.h,v 1.13 2006/04/04 22:07:32 dsalt Exp $
- *
  * init xine engine, set up script engine with player object
  */
 
-#ifndef HAVE_ENGINE_H
-#define HAVE_ENGINE_H
+#ifndef GXINE_ENGINE_H
+#define GXINE_ENGINE_H
 
 #include <glib.h>
 #include "script_engine.h"
