@@ -38,6 +38,7 @@
 #include <sys/types.h>
 #include <pthread.h>
 #include <sched.h>
+#include <sys/time.h>
 
 #include <X11/Xlib.h>
 #include <X11/keysym.h>
@@ -100,14 +101,19 @@ static void gtk_video_map (GtkWidget *);
 
 /*
 static void gtk_video_size_request (GtkWidget      *widget,
-		       		    GtkRequisition *requisition);
+				    GtkRequisition *requisition);
 */
 static void gtk_video_size_allocate (GtkWidget      *widget,
- 				     GtkAllocation  *allocation);
+				     GtkAllocation  *allocation);
 
 static gboolean gtv_unblank_screen (GtkVideo *);
 static gboolean gtv_update_resize_factor (GtkVideo *);
 
+static int screensaver_poke (const char *const [], const char *);
+#ifdef XDG_SCREENSAVER_COMMAND
+static int xdg_screensaver_poke (const char *, Window);
+#endif
+
 static GtkWidgetClass *parent_class = NULL;
 static pthread_mutex_t resize_lock = PTHREAD_MUTEX_INITIALIZER;
 static pthread_mutex_t resize_add_lock = PTHREAD_MUTEX_INITIALIZER;
@@ -164,12 +170,18 @@ struct gtk_video_private_s {
   gboolean		   idle_resized:8;
   gboolean		   hinted:8;
 
-  /* fullscreen stuff */
+  /* fullscreen & pointer stuff */
 
   gboolean		   fullscreen_mode:8, pointer_visible:8;
   GtkRequisition	   fullscreen;
-  Cursor                   pointer[2];
-  guint			   pointer_hide_timeout, screen_blanker_timeout;
+  Cursor		   pointer[3];
+  uint8_t		   pointer_shape, pointer_shape_old;
+  struct {
+    struct timeval	   time;
+    gboolean		   in:8;
+  }			   spu;
+  guint			   pointer_hide_timeout;
+  guint			   screen_blanker_timeout;
   guint			   unblock_timeout;
 
   gint			   screen_signal;
@@ -185,6 +197,11 @@ struct gtk_video_private_s {
   guint32		 cookie;
 #endif
 
+#ifdef XDG_SCREENSAVER_COMMAND
+  Window		 xdg_active;
+  gboolean		 have_xdg_screensaver:8;
+#endif
+
   gboolean		 playing_no_blank:8;
 
   /* visualisation & post-plugins*/
@@ -413,11 +430,16 @@ GtkType gtk_video_get_type (void)
 static void gtv_set_pointer (GtkVideo *gtv, gboolean state)
 {
   Display *display = gtv_get_xdisplay (gtv);
-  gtv->priv->pointer_visible = state;
-  XLockDisplay (display);
-  XDefineCursor (display, gtv->priv->video_window, gtv->priv->pointer[!!state]);
-  XFlush (display);
-  XUnlockDisplay (display);
+  if (gtv->priv->pointer_visible != state || gtv->priv->pointer_shape != gtv->priv->pointer_shape_old)
+  {
+    XLockDisplay (display);
+    gtv->priv->pointer_visible = state;
+    gtv->priv->pointer_shape_old = gtv->priv->pointer_shape;
+    XDefineCursor (display, gtv->priv->video_window,
+		   gtv->priv->pointer[state ? gtv->priv->pointer_shape + 1 : 0]);
+    XFlush (display);
+    XUnlockDisplay (display);
+  }
 }
 
 static gboolean gtv_hide_pointer_cb (GtkVideo *gtv)
@@ -427,6 +449,12 @@ static gboolean gtv_hide_pointer_cb (GtkVideo *gtv)
   return FALSE;
 }
 
+static gboolean gtv_set_pointer_cb (GtkVideo *gtv)
+{
+  gtv_set_pointer (gtv, gtv->priv->pointer_visible);
+  return FALSE;
+}
+
 static void gtv_show_pointer (GtkVideo *gtv)
 {
   if (gtv->priv->pointer_hide_timeout)
@@ -450,6 +478,13 @@ static void gtv_hide_pointer (GtkVideo *gtv)
   gtv_set_pointer (gtv, FALSE);
 }
 
+static void gtv_set_pointer_shape (GtkVideo *gtv, int shape)
+{
+  gtv->priv->pointer_shape = shape;
+  gtv->priv->pointer_visible = TRUE;
+  g_idle_add ((GSourceFunc)gtv_set_pointer_cb, gtv);
+}
+
 #ifdef HAVE_XTESTEXTENSION
 /* Track the Shift keys: we need to ensure that they "remain pressed" when
  * blocking the screen blanker when in full-screen mode.
@@ -609,7 +644,7 @@ static gboolean gtv_idle_resize (GtkVideo *gtv, gboolean resize)
   priv->size = SCALE (factor);
 
   logprintf ("gtkvideo: idle resize to %d x %d (factor %lf)\n",
-             priv->size.width, priv->size.height, factor);
+	     priv->size.width, priv->size.height, factor);
 
   if (is_fullscreen (priv) || !GTK_WIDGET_VISIBLE (&gtv->widget))
   {
@@ -716,12 +751,12 @@ static void frame_output_cb (void *gv_gen,
       if (first ||
 	  video_width != priv->size.width || video_height != priv->size.height)
       {
-        if (is_fullscreen (priv) || !GTK_WIDGET_VISIBLE (&gtv->widget))
-        {
-          priv->size = (GtkRequisition){ video_width, video_height };
-          priv->pending_resize = TRUE;
-        }
-        else
+	if (is_fullscreen (priv) || !GTK_WIDGET_VISIBLE (&gtv->widget))
+	{
+	  priv->size = (GtkRequisition){ video_width, video_height };
+	  priv->pending_resize = TRUE;
+	}
+	else
 	  RESIZE_ADD (first || priv->auto_resize);
       }
     }
@@ -892,6 +927,33 @@ uint32_t gtk_video_get_capabilities (GtkVideo *this)
   return priv->video_port->get_capabilities (priv->video_port);
 }
 
+static inline double mkdtime (const struct timeval *tv)
+{
+  return tv->tv_sec + tv->tv_usec / 1000000.0;
+}
+
+gboolean gtk_video_in_spu_button (GtkVideo *gtv, int dir)
+{
+  gtk_video_private_t *priv = gtv->priv;
+
+  if (dir >= 0)
+  {
+    priv->spu.in = !!dir;
+    gtv_set_pointer_shape (gtv, !!dir);
+    if (dir)
+      gettimeofday (&priv->spu.time, NULL);
+  }
+
+  if (priv->spu.in)
+    return TRUE;
+
+  /* timeout of 1s from when a button is entered */
+  struct timeval now;
+  gettimeofday (&now, NULL);
+
+  return mkdtime (&now) - mkdtime (&priv->spu.time) <= 1.0;
+}
+
 static void gtv_send_xine_mouse_event (gtk_video_private_t *priv,
 				       int x, int y, int button)
 {
@@ -905,8 +967,8 @@ static void gtv_send_xine_mouse_event (gtk_video_private_t *priv,
   rect.h = 0;
 
   xine_port_send_gui_data (priv->video_port,
-                           XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO,
-                           (void *) &rect);
+			   XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO,
+			   (void *) &rect);
 
   xev.type	  = button ? XINE_EVENT_INPUT_MOUSE_BUTTON
 			   : XINE_EVENT_INPUT_MOUSE_MOVE;
@@ -991,7 +1053,7 @@ static GdkFilterReturn xevent_filter_cb (XEvent *const xev, GdkEvent *const ev,
       if (xev->xbutton.state & ShiftMask)
 	priv->button_event_shifted |= 1 << xev->xbutton.button;
     }
-    return GDK_FILTER_REMOVE;
+    return gtk_video_in_spu_button (gtv, -1) ? GDK_FILTER_REMOVE : GDK_FILTER_CONTINUE;
 
   case ButtonRelease:
     /* permit the GTK event if allowed *and* Shift wasn't pressed when
@@ -1230,7 +1292,7 @@ static void gtk_video_realize (GtkWidget *widget)
   /* not sure why this is needed in some situations... */
   XEvent event;
   XCheckWindowEvent (xdisplay, priv->video_window, -1, &event);
-      
+
   widget->window = gdk_window_foreign_new_for_display
 		     (display, priv->video_window);
   if (!widget->window)
@@ -1310,9 +1372,14 @@ static void gtk_video_realize (GtkWidget *widget)
   priv->pointer[0] = XCreatePixmapCursor (xdisplay, bm_no, bm_no,
 					  &black_pixel, &black_pixel, 0, 0);
   priv->pointer[1] = XCreateFontCursor (xdisplay, XC_left_ptr);
+  priv->pointer[2] = XCreateFontCursor (xdisplay, XC_hand1);
   priv->pointer_visible = TRUE;
   XUnlockDisplay (xdisplay);
 
+#ifdef XDG_SCREENSAVER_COMMAND
+  priv->xdg_active = 0;
+  priv->have_xdg_screensaver = !xdg_screensaver_poke ("--help", 0);
+#endif
   priv->screen_blanker_timeout =
     g_timeout_add (4000, (GSourceFunc) gtv_screen_blanker_cb, gtv);
 }
@@ -1370,10 +1437,10 @@ static void gtk_video_map (GtkWidget *widget)
 }
 
 GtkWidget *gtk_video_new (xine_t *xine, xine_stream_t *stream,
-    		          xine_post_out_t *out,
-                          const gchar *video_driver_id,
-                          int default_width, int default_height,
-                          int button_press_mask, int button_release_mask)
+			  xine_post_out_t *out,
+			  const gchar *video_driver_id,
+			  int default_width, int default_height,
+			  int button_press_mask, int button_release_mask)
 {
   GtkWidget	      *this = g_object_new (gtk_video_get_type (), NULL);
   GtkVideo            *gtv = (GtkVideo *) this;
@@ -1396,6 +1463,7 @@ GtkWidget *gtk_video_new (xine_t *xine, xine_stream_t *stream,
   priv->post_video.list = NULL;
   priv->post_audio.list = NULL;
   priv->frame_cb = NULL;
+  priv->pointer_shape_old = -1;
 
   if (video_driver_id)
     priv->video_driver_id = strdup (video_driver_id);
@@ -1463,7 +1531,7 @@ static gboolean gtv_update_resize_factor (GtkVideo *this)
 }
 
 static void gtk_video_size_allocate (GtkWidget *widget,
-    				     GtkAllocation *allocation)
+				     GtkAllocation *allocation)
 {
   GtkVideo *this;
 
@@ -1630,6 +1698,16 @@ void gtk_video_set_fullscreen (GtkVideo *gtv, gint fullscreen)
 
     priv->fullscreen_mode = FALSE;
   }
+/* pointer motion will take care of this
+  struct {
+    Window root, child;
+    int rx, ry, x, y, mask;
+  } pos;
+  XQueryPointer (display, GDK_WINDOW_XWINDOW (gtv->widget.window),
+		 &pos.root, &pos.child, &pos.rx, &pos.ry,
+		 &pos.x, &pos.y, &pos.mask);
+  gtv_send_xine_mouse_event (priv, pos.x, pos.y, 0);
+*/
 
   XUnlockDisplay (display);
   g_static_rec_mutex_unlock (&engine_lock);
@@ -2179,6 +2257,7 @@ gboolean gtk_video_get_auto_rescale (GtkVideo *gtv)
   return (gtv && gtv->priv) ? gtv->priv->auto_rescale : FALSE;
 }
 
+#if defined(XDG_SCREENSAVER_COMMAND) || defined(GNOME_SCREENSAVER_COMMAND) || defined(X_SCREENSAVER_COMMAND)
 static int screensaver_poke (const char *const argv[], const char *name)
 {
   int ret = 60; /* default return = try again in 4 minutes */
@@ -2207,15 +2286,53 @@ static int screensaver_poke (const char *const argv[], const char *name)
       }
     g_error_free (err);
   }
+  else
+    ret = 0;
 
   return ret;
 }
+#endif
+
+#ifdef XDG_SCREENSAVER_COMMAND
+static int xdg_screensaver_poke (const char *arg, Window id)
+{
+  char id_str[16];
+  const char *const argv[] = { XDG_SCREENSAVER_COMMAND, arg,
+			       id ? id_str : NULL, NULL };
+  sprintf (id_str, "%#x", (int) id);
+  /* screensaver name is used in "can't poke <name>" */
+  return screensaver_poke (argv, "xdg-screensaver");
+}
+#endif
 
 static gboolean gtv_unblank_screen (GtkVideo *gtv)
 {
   static gboolean dbus_deny = FALSE;
+  gboolean inhibit = gtv_test_inhibit_blank (gtv);
 
-  if (!gtv_test_inhibit_blank (gtv))
+#ifdef XDG_SCREENSAVER_COMMAND
+  if (gtv->priv->have_xdg_screensaver)
+  {
+    if (inhibit != !!gtv->priv->xdg_active)
+    {
+      Window id = inhibit
+		? gdk_x11_drawable_get_xid (gtk_widget_get_toplevel (&gtv->widget)->window)
+		: gtv->priv->xdg_active;
+      int ret = 0;
+      if (!id || !(ret = xdg_screensaver_poke (inhibit ? "suspend" : "resume", id)))
+      {
+	if (ret < 0) /* if this happens, xdg-screensaver isn't there */
+	  gtv->priv->have_xdg_screensaver = 0;
+	gtv->priv->xdg_active = inhibit ? id : 0;
+	return FALSE;
+      }
+    }
+    else
+      return FALSE; /* nothing to do */
+  }
+#endif
+
+  if (!inhibit)
   {
     if (dbus_deny)
       gtv_screensaver_maybe_inhibit_dbus (gtv->priv, dbus_deny = FALSE);
