@@ -15,8 +15,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: history.c,v 1.2 2006/03/27 22:11:24 dsalt Exp $
- *
  * GtkComboBox with history
  *
  */
@@ -70,13 +68,13 @@ activate_cb (GtkWidget *w, gpointer cb)
 }
 
 static void
-set_iter (GtkWidget *w, GtkScrollType dir)
+set_iter (GtkComboBox *w, GtkScrollType dir)
 {
   GtkEditable *edit = GTK_EDITABLE (GTK_BIN (w)->child);
-  int item = gtk_combo_box_get_active (GTK_COMBO_BOX (w));
+  int item = gtk_combo_box_get_active (w);
   int prev = item;
   int last = gtk_tree_model_iter_n_children
-    (gtk_combo_box_get_model (GTK_COMBO_BOX (w)), NULL) - 1;
+    (gtk_combo_box_get_model (w), NULL) - 1;
 
   switch (dir)
   {
@@ -99,7 +97,7 @@ set_iter (GtkWidget *w, GtkScrollType dir)
     eval_text = gtk_editable_get_chars (edit, 0, -1);
   }
 
-  gtk_combo_box_set_active (GTK_COMBO_BOX (w), item);
+  gtk_combo_box_set_active (w, item);
 
   if (item < 0)
   {
@@ -111,7 +109,7 @@ set_iter (GtkWidget *w, GtkScrollType dir)
 }
 
 static gboolean
-scroll_cb (GtkWidget *w, GdkEventKey *e, GtkWidget *t)
+scroll_cb (GtkComboBox *w, GdkEventKey *e, GtkWidget *t)
 {
   switch (e->state & GXINE_MODIFIER_MASK)
   {
