@@ -1,27 +1,26 @@
 /*
- * Copyright (C) 2002 the xine project
- * 
+ * Copyright (C) 2002-2006 the xine project
+ *
  * This file is part of xine, a free video player.
- * 
+ *
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * xine is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
  *
- * $Id: http.h,v 1.6 2006/04/04 22:08:52 dsalt Exp $
  */
 
-#ifndef HAVE_HTTP_H
-#define HAVE_HTTP_H
+#ifndef GXINE_HTTP_H
+#define GXINE_HTTP_H
 
 
 char *http_download (const char *url, ssize_t *file_size);
