@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2005 the xine-project
+ * Copyright (C) 2002-2006 the xine-project
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,12 +16,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: info_widgets.h,v 1.6 2006-02-21 19:06:12 dsalt Exp $
- *
  * nice black information display areas
  */
-#ifndef HAVE_INFO_WIDGETS_H
-#define HAVE_INFO_WIDGETS_H
+#ifndef GXINE_INFO_WIDGETS_H
+#define GXINE_INFO_WIDGETS_H
 
 #include <gtk/gtk.h>
 
@@ -29,13 +27,13 @@ typedef GtkAlignment GtkGxineInfo;
 typedef GtkAlignmentClass GtkGxineInfoClass;
 
 GtkWidget *create_infobar (gboolean small);
-GtkWidget *create_time_widget (gboolean small);
+GtkWidget *create_time_widget (gboolean small, const GSList *const *const);
 
-void gxineinfo_update_line (GSList *, guint, const char *, ...)
+void gxineinfo_update_line (const GSList *, guint, const char *, ...)
   __attribute__ ((format (printf, 3, 4)));
-void gxineinfo_update (GSList *);
-void gxineinfo_clear (GSList *);
+void gxineinfo_update (const GSList *);
+void gxineinfo_clear (const GSList *);
 
-void infobar_show_metadata (GSList *);
+void infobar_show_metadata (const GSList *);
 
 #endif
