@@ -192,7 +192,7 @@ static gboolean is_menu_accel (GtkWidget *w, const GdkEventKey *event)
   get_menu_bar_accel (w, &keyval, &mods);
   return event->keyval == keyval &&
 	 (event->state & GXINE_MODIFIER_MASK) == (mods & GXINE_MODIFIER_MASK);
-}  
+}
 
 gboolean keypress_cb (GtkWidget *win, GdkEventKey *event, gpointer data)
 {
@@ -209,8 +209,8 @@ gboolean keypress_cb (GtkWidget *win, GdkEventKey *event, gpointer data)
 	  (key_binding->keyval == keyval ||
 	   key_binding->keyval == ~event->hardware_keycode))
       {
-        char *binding = kb2str (key_binding);
-        asreprintf (&binding, _("key binding %s"), binding);
+	char *binding = kb2str (key_binding);
+	asreprintf (&binding, _("key binding %s"), binding);
 	/* defer execution of commands due to keypresses during startup */
 	engine_queue_push (key_binding->cmd, NULL, NULL, NULL, NULL, binding);
 	free (binding);
@@ -259,10 +259,15 @@ gboolean keypress_cb (GtkWidget *win, GdkEventKey *event, gpointer data)
 
 gboolean buttonpress_cb (GtkWidget *win, GdkEventButton *event, gpointer data)
 {
-  /* Full-screen toolbar toggle (middle button) */
   if (!(event->state & GXINE_MODIFIER_MASK))
     switch (event->button)
     {
+    /* Full-screen toggle */
+    case 1:
+      if (event->type == GDK_2BUTTON_PRESS && !gtk_video_in_spu_button (gtv, -1))
+	gtk_action_activate (GTK_ACTION (action_items.fullscreen));
+      return TRUE;
+    /* Toolbar toggle (middle button) */
     case 2:
       if (gtk_video_is_fullscreen ((GtkVideo *)gtv))
 	gtk_action_activate (GTK_ACTION(action_items.fs_toolbar));
@@ -426,7 +431,7 @@ static void modify_key_binding (GtkTreeIter *iter, key_binding_t *key_binding,
     int i = -1;
     while (default_bindings[++i].desc)
       if (!strcasecmp (default_bindings[i].cmd, new_binding->cmd))
-        break;
+	break;
     key_binding->desc  = strdup (default_bindings[i].desc ? : new_binding->cmd);
   }
   else
@@ -700,9 +705,9 @@ static void load_key_bindings (void)
 	    break;
 	  }
 
-        if (version < 2)
-        {
-          display_info (FROM_GXINE, _("Upgrading your key bindings"),
+	if (version < 2)
+	{
+	  display_info (FROM_GXINE, _("Upgrading your key bindings"),
 			_("Your key bindings are being upgraded. This adds:\n"
 			" • Key binding descriptions\n"
 			" • VDR support\n"
@@ -710,10 +715,10 @@ static void load_key_bindings (void)
 			"Some old deleted bindings may have been restored.\n"
 			"You should check your bindings now.\n")
 			);
-          load_default_kb ();
-        }
-        else if (version < 3)
-          display_info (FROM_GXINE, _("Upgrading your key bindings"), "");
+	  load_default_kb ();
+	}
+	else if (version < 3)
+	  display_info (FROM_GXINE, _("Upgrading your key bindings"), "");
 
 	xml_node_t *node;
 	foreach_glist (node, root->child)
@@ -941,7 +946,7 @@ static gboolean do_edit_key_cb (GtkWidget *widget, GdkEventKey *event,
     return TRUE;
   if (event->keyval == GDK_Menu && !(event->state & GXINE_MODIFIER_MASK))
     return TRUE;
-  
+
   if (is_menu_accel (widget, event))
     return TRUE;
 
@@ -1284,7 +1289,7 @@ JSBool js_event_generic (JSContext *cx, JSObject *obj, uintN argc, jsval *argv,
 	++prefix;
       }
       if (!*prefix) /* no match found */
-        return JS_TRUE;
+	return JS_TRUE;
     }
   }
 
@@ -1324,7 +1329,7 @@ static JSBool js_event (JSContext *cx, JSObject *obj, uintN argc,
 static JSBool js_vdr (JSContext *cx, JSObject *obj, uintN argc,
 		      jsval *argv, jsval *rval)
 {
-  const char *const prefixes[] = { "vdr:/", "vdr-socket:/", NULL };
+  const char *const prefixes[] = { "vdr:/", "netvdr:/", NULL };
   return js_event_generic (cx, obj, argc, argv, rval, "vdr", prefixes,
 			   &xine_vdr, NULL);
 }
@@ -1418,7 +1423,7 @@ void key_events_init (void)
       { "binding", NULL,			N_("_Reload...") },
       { "reload",  GTK_STOCK_REVERT_TO_SAVED,	N_("_Reload bindings"),			NULL,		NULL,				kb_reload_keymap },
       { "addnew",  GTK_STOCK_ADD,		N_("_Add new default bindings"),	NULL,		NULL,				kb_add_defaults },
-      { "merge",   NULL,			N_("_Merge default bindings"),	   	NULL,		NULL,				kb_merge_defaults },
+      { "merge",   NULL,			N_("_Merge default bindings"),		NULL,		NULL,				kb_merge_defaults },
       { "replace", GTK_STOCK_CLEAR,		N_("Replace with _default bindings"),	NULL,		NULL,				kb_reset_keymap },
       { "new",	   GTK_STOCK_NEW,		NULL,					NULL,		N_("Add a key binding"),	kb_new_binding },
       { "edit",	   GTK_STOCK_EDIT,		NULL,					"<Control>E",	N_("Edit the selected item"),	kb_edit_binding },
