@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2005 the xine-project
+ * Copyright (C) 2001-2006 the xine-project
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,13 +16,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: key_events.h,v 1.10 2006-03-10 19:24:51 dsalt Exp $
- *
  * key event handler, keymap editor
  */
 
-#ifndef HAVE_KEY_EVENTS_H
-#define HAVE_KEY_EVENTS_H
+#ifndef GXINE_KEY_EVENTS_H
+#define GXINE_KEY_EVENTS_H
 
 #include <gtk/gtk.h>
 
@@ -39,6 +37,8 @@ struct kb_xine_event_map_s {
 };
 typedef struct kb_xine_event_map_s kb_xine_event_map_t;
 
+void get_menu_bar_accel (GtkWidget *, guint *, GdkModifierType *);
+
 gboolean keypress_cb (GtkWidget *, GdkEventKey *, gpointer);
 gboolean buttonpress_cb (GtkWidget *, GdkEventButton *, gpointer);
 gboolean buttonrelease_cb (GtkWidget *, GdkEventButton *, gpointer);
