@@ -16,8 +16,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: lirc.c,v 1.22 2006/04/04 22:07:32 dsalt Exp $
- *
  * lirc (infrared control) code, originally based on oxine
  */
 
@@ -105,19 +103,25 @@ static __attribute__ ((noreturn)) void *gxine_lirc_run (void *data)
     {
       if ((gxine_lirc_fd = lirc_init ("gxine", 0)) != -1)
       {
-        if (!first)
-          logprintf ("lirc: reconnected\n");
-        break;
+	if (!first)
+	  logprintf ("lirc: reconnected\n");
+	break;
       }
 
       if (!first)
       {
-        sleep (1);
-        continue;
+	pthread_cond_signal (&lirc_init_cond);
+	pthread_mutex_unlock (&lirc_init_mutex);
+	pthread_cleanup_push (gxine_lirc_cleanup, NULL);
+	sleep (1);
+	pthread_testcancel();
+	pthread_cleanup_pop (0);
+	pthread_mutex_lock (&lirc_init_mutex);
+	continue;
       }
 
       g_printerr (_("lirc: cannot initialise - disabling remote control\n"
-	         "lirc: maybe lircd isn't running or you can't connect to the socket?\n"));
+		 "lirc: maybe lircd isn't running or you can't connect to the socket?\n"));
       failed:
       gxine_lirc_thread = 0;
       pthread_cond_signal (&lirc_init_cond);
@@ -149,12 +153,12 @@ static __attribute__ ((noreturn)) void *gxine_lirc_run (void *data)
 
       if (lirc_nextcode (&code) == 0)
       {
-        pthread_testcancel();
+	pthread_testcancel();
 
-        if (code != NULL)
-        {
+	if (code != NULL)
+	{
 	  int ret;
-          while ((ret = lirc_code2char (lircconfig, code, &config) == 0)
+	  while ((ret = lirc_code2char (lircconfig, code, &config) == 0)
 		 && config != NULL)
 	  {
 	    char *src = g_strdup_printf (_("LIRC binding %s.%s"),
@@ -164,14 +168,14 @@ static __attribute__ ((noreturn)) void *gxine_lirc_run (void *data)
 	  }
 
 	  free(code);
-        }
+	}
       }
       else
       {
 	/* lircd has exited? try reinitialising in case it's been restarted */
 	logprintf ("lirc: socket read error\n");
-        pthread_testcancel();
-        break;
+	pthread_testcancel();
+	break;
       }
     }
 
