@@ -110,7 +110,7 @@ gxine_try_remote (int argc, char *argv[], gboolean enqueue, gboolean autoplay)
     for (i = optind; i < argc; ++i)
     {
       if (autoplay && i == optind)
-        server_client_send ("playlist_play (");
+	server_client_send ("playlist_play (");
       server_client_send ("playlist_add (\"");
       char *uri = make_path_uri (argv[i]);
       server_client_send (uri ? uri : argv[i]);
@@ -353,7 +353,7 @@ static void config_change (gpointer data, gpointer user)
     g_printerr (_("gxine: warning: config item '%s' not found\n"), text);
 
   *equals = '=';
-}  
+}
 
 int main(int argc, char* argv[])
 {
@@ -554,7 +554,7 @@ options:\n\
   -f, --full-screen	start in full-screen mode\n\
   -v, --verbose		be more verbose\n\
   -C, --configure KEY=VALUE\n\
-                        alter a configuration item\n\
+			alter a configuration item\n\
 \n"), VERSION, VENDOR_PKG_VERSION CSET_ID, argv[0]);
     list_plugins (_("Available video drivers:"), gxine_list_video_output_plugins);
     list_plugins (_("Available audio drivers:"), xine_list_audio_output_plugins);
@@ -683,16 +683,15 @@ to the extent permitted by law.\n"),
   if (migrated_config_dir && xine_config_get_first_entry (xine, &entry))
   {
     int oldlen = strlen (oldconfig);
-  
+
     do
     {
-      if (entry.type == XINE_CONFIG_TYPE_STRING &&
-          (!xine_check_version (1, 1, 4) || entry.num_value) &&
-          !strncmp (entry.str_value, oldconfig, oldlen) &&
-          (entry.str_value[oldlen] == '/' || entry.str_value[oldlen] == 0))
+      if (entry.type == XINE_CONFIG_TYPE_STRING && entry.num_value &&
+	  !strncmp (entry.str_value, oldconfig, oldlen) &&
+	  (entry.str_value[oldlen] == '/' || entry.str_value[oldlen] == 0))
       {
 	entry.str_value = g_strconcat (newconfig, entry.str_value + oldlen, NULL);
-        logprintf (_("updating config item %s to %s\n"), entry.key, entry.str_value);
+	logprintf (_("updating config item %s to %s\n"), entry.key, entry.str_value);
 	xine_config_update_entry (xine, &entry);
 	g_free (entry.str_value);
       }
@@ -716,7 +715,7 @@ to the extent permitted by law.\n"),
   ui_init ();
 
   gtk_window_set_default_icon_name (GXINE_LOGO);
-  
+
 
   {
     char *fname = get_config_filename (FILE_ACCELS);
