@@ -1,5 +1,5 @@
-/* 
- * Copyright (C) 2003-2005 the xine project
+/*
+ * Copyright (C) 2003-2007 the xine project
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,8 +15,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: menu.c,v 1.82 2006/04/08 21:34:50 dsalt Exp $
- *
  * main/context menu creation / handling
  */
 
@@ -33,6 +31,7 @@
 #include "utils.h"
 #include "gtkvideo.h"
 #include "vis.h"
+#include "noskin_window.h"
 
 /*
  * global variables
@@ -52,31 +51,6 @@ action_items_t action_items = { NULL };
 #define get_radio(name) GTK_RADIO_ACTION(get_action ((name)))
 #define get_radio_group(name) gtk_radio_action_get_group (get_radio ((name)))
 
-/*
- * context menu
- */
-
-#if 0
-static gint context_menu_cb (GtkWidget *widget, GdkEvent *event) {
-
-  if (event->type == GDK_BUTTON_PRESS) {
-    GdkEventButton *bevent = (GdkEventButton *) event; 
-
-    if (bevent->button == 3) {
-      gtk_menu_popup (GTK_MENU(widget), NULL, NULL, NULL, NULL,
-		      bevent->button, bevent->time);
-      /* Tell calling code that we have handled this event; the buck
-       * stops here. */
-      return TRUE;
-    }
-  }
-  
-  /* Tell calling code that we have not handled this event; pass it on. */
-  return FALSE;
-}
-#endif
-
-
 static const char type[][8] = { "menubar", "popup" };
 
 const char *menu_get_tree_name (unsigned int tree)
@@ -86,16 +60,14 @@ const char *menu_get_tree_name (unsigned int tree)
 
 static void autoplay_cb (GtkAction *action, const char *data)
 {
-  char **mrls;
-  int    n, i, pos;
+  int n, i, pos;
 
-  mrls = xine_get_autoplay_mrls (xine, data, &n);
-
-  if (!mrls) {
-    char *title;
-    playlist_logo();
-    title = g_markup_printf_escaped (_("Autoplay input plugin ‘%s’ failed"),
-				     data);
+  char **mrls = xine_get_autoplay_mrls (xine, data, &n);
+  if (!mrls)
+  {
+    playlist_logo (NULL);
+    char *title = g_markup_printf_escaped (_("Autoplay input plugin ‘%s’ failed"),
+					   data);
     display_error (FROM_XINE, title, _("Check engine output for further details."));
     free (title);
     return;
@@ -110,16 +82,16 @@ static void autoplay_cb (GtkAction *action, const char *data)
     {
       int j;
       for (j = playlist_size () - 1; j >= 0; --j)
-        if (!strcmp (playlist_get_item (j)->mrl, mrls[i]))
-          break;
+	if (!strcmp (playlist_get_item (j)->mrl, mrls[i]))
+	  break;
       if (j >= 0)
       {
-        pos = j;
-        continue;
+	pos = j;
+	continue;
       }
     }
 
-    play_item_t *item = play_item_new (NULL, mrls[i], 0);
+    play_item_t *item = play_item_new (NULL, mrls[i], 0, 0);
     item->type = PLAY_ITEM_AUTOPLAY;
     if (pos < 0)
       pos = playlist_add (item, -1);
@@ -150,7 +122,8 @@ static size_t add_autoplay_actions (GtkUIManager *ui)
     { "CD", GTK_STOCK_CDROM },
   };
 
-  if (!autoplay_ids) {
+  if (!autoplay_ids)
+  {
     logprintf ("menu: warning: didn't get any autoplay entries\n");
     return 0;
   }
@@ -287,12 +260,18 @@ JS_CB (Prefs, "preferences_show ();")
 JS_CB (Keys, "keybindings_show ();")
 JS_CB (Startup, "startup_cmds_show ();")
 JS_CB (Snapshot, "snapshot ();")
+JS_CB (HideMain, "set_minimised (1);")
+JS_CB (ShowMain, "set_minimised (0);")
 JS_CB (Quit, "exit ();")
 
 /* View */
 JS_CB_T (Fullscreen)
 {
+  if (!GTK_WIDGET_MAPPED (app))
+    app_show ();
   gtk_video_set_fullscreen ((GtkVideo *)gtv, v);
+  gtk_action_set_sensitive (action_items.hidemain, !v);
+  gtk_action_set_sensitive (action_items.showmain, !v);
   if (v)
     window_fs_toolbar_restore ();
   else
@@ -326,6 +305,11 @@ JS_CB_T (Deinterlace)
 JS_CB_T (VideoPP) { gtk_video_set_use_post_plugins_video ((GtkVideo *)gtv, v); }
 JS_CB (DeinterlaceConf, "deinterlace_show ();")
 JS_CB (VideoPPConf, "postproc_video_show ();")
+JS_CB_T (WMUnblank)
+{
+  gtk_video_set_windowed_unblank ((GtkVideo *)gtv, v);
+}
+JS_CB_T (FSSticky) { window_fs_stickiness_update (v); }
 
 /* Audio */
 JS_CB (AudioSettings, "settings_show (1);")
@@ -353,6 +337,14 @@ JS_CB (SetupWizards, "run_wizards ();")
 JS_CB (ReloadLIRC, "reload_lirc ();")
 #endif
 
+/* Systray */
+JS_CB (PrevTrack, "playlist_play (playlist_get_item () - 1);")
+JS_CB (NextTrack, "playlist_play (playlist_get_item () + 1);")
+JS_CB (Play, "play ();")
+JS_CB (Pause, "if (!is_live_stream ()) pause ();")
+JS_CB (FFwd, "if (!is_live_stream ()) av_speed.v = 5;")
+JS_CB (Stop, "stop ();")
+
 #define CB(name, stock, label, key) \
   { #name, (stock), (label), (key), NULL, G_CALLBACK(js_##name##_cb) }
 static const GtkActionEntry main_actions[] = {
@@ -371,6 +363,8 @@ static const GtkActionEntry main_actions[] = {
   CB(Snapshot,		NULL,			N_("_Snapshot..."),		"<control>S"),
   CB(Quit,		GTK_STOCK_QUIT,		N_("_Quit"),			"<control>Q"),
   { "ViewMenu",		NULL,			N_("_View") },
+  CB(HideMain,		GTK_STOCK_CLOSE,	N_("_Hide video"),		"<control>W"),
+  CB(ShowMain,		NULL,			N_("_Show video"),		NULL),
   { "ToolbarMenu",	NULL,			N_("_Toolbars") },
   { "WindowMenu",	NULL,			N_("_Window size") },
   CB(WindowRevert,	NULL,			N_("Re_set"),			NULL),
@@ -380,28 +374,35 @@ static const GtkActionEntry main_actions[] = {
   CB(Zoom100,		GTK_STOCK_ZOOM_100,	N_("_Zoom 100%"),		NULL),
   { "AspectMenu",	NULL,			N_("_Aspect ratio"),		NULL },
   { "VisMenu",		NULL,			N_("_Visualisations"),		NULL },
-  { "SubsMenu",		NULL,			N_("_Subtitles"),		NULL },
+  { "SubsMenu",		"gxine-settings-spu",	N_("_Subtitles"),		NULL },
+  { "ViewMisc",		GTK_STOCK_PROPERTIES,	N_("_Settings"),		NULL },
   { "VideoMenu",	NULL,			N_("V_ideo"),			NULL },
-  CB(VideoSettings,	GTK_STOCK_PROPERTIES,	/* Video */ N_("_Settings..."),	NULL),
-  { "VideoConfigMenu",	NULL,			N_("_Configure"),		NULL },
-  CB(DeinterlaceConf,	GTK_STOCK_PREFERENCES,	N_("_Deinterlace..."),		NULL),
-  CB(VideoPPConf,	GTK_STOCK_PREFERENCES,	N_("_Post-processing..."), 	NULL),
+  CB(VideoSettings,	GTK_STOCK_PROPERTIES,	/* Video */ N_("_Controls..."),	NULL),
+  { "VideoConfigMenu",	GTK_STOCK_PREFERENCES,	N_("_Configure plugins"),	NULL },
+  CB(DeinterlaceConf,	NULL,			N_("_Deinterlace..."),		NULL),
+  CB(VideoPPConf,	NULL,			N_("_Video post-processing..."),NULL),
   { "AudioMenu",	NULL,			N_("_Audio"),			NULL },
-  CB(AudioSettings,	GTK_STOCK_PROPERTIES,	/* Audio */ N_("_Settings..."),	NULL),
+  CB(AudioSettings,	GTK_STOCK_PROPERTIES,	/* Audio */ N_("_Controls..."),	NULL),
   CB(AudioEq,		GTK_STOCK_PROPERTIES,	N_("_Equaliser..."),		NULL),
-  { "AudioConfigMenu",	NULL,			N_("_Configure"),		NULL },
-  CB(AudioPPConf,	GTK_STOCK_PREFERENCES,	N_("_Post-processing..."),	NULL),
+  { "AudioConfigMenu",	GTK_STOCK_PREFERENCES,	N_("_Configure plugins"),		NULL },
+  CB(AudioPPConf,	NULL,			N_("_Audio post-processing..."),NULL),
   { "MediaMenu",	NULL,			N_("_Media"),			NULL },
-  CB(MediaAdd,		GTK_STOCK_NEW,		N_("_Add media mark.."),	"<control>D"),
+  CB(MediaAdd,		GTK_STOCK_NEW,		N_("_Add media mark..."),	"<control>D"),
   CB(MediaManage,	GXINE_MEDIA_MARK,	N_("_Manage media marks..."),	"<control>B"),
   CB(MediaImport,	GTK_STOCK_OPEN,		N_("_Import media marks..."),	NULL),
   { "ToolsMenu",	NULL,			N_("_Tools"),			NULL },
   CB(EngineLog,		NULL,			N_("Engine _log..."),		"<control>L"),
   CB(JSConsole,		GTK_STOCK_EXECUTE,	N_("_Javascript console..."),	"<control>J"),
-  CB(StreamInfo,	"gtk-info",		N_("Stream _info..."),		NULL),
+  CB(StreamInfo,	GTK_STOCK_INFO,		N_("Stream _info..."),		NULL),
   CB(SetupWizards,	GTK_STOCK_REDO,		N_("_Re-run setup wizards..."), NULL),
   { "HelpMenu",		NULL,			N_("_Help"),			NULL },
   CB(About,		GTK_STOCK_ABOUT,	N_("_About..."),		NULL),
+  CB(PrevTrack,	GTK_STOCK_MEDIA_PREVIOUS,	N_("Pre_vious track"),		NULL),
+  CB(Play,	GTK_STOCK_MEDIA_PLAY,		N_("_Play"),			NULL),
+  CB(Pause,	GTK_STOCK_MEDIA_PAUSE,		N_("_Pause"),			NULL),
+  CB(FFwd,	GTK_STOCK_MEDIA_FORWARD,	N_("_Fast forward"),		NULL),
+  CB(Stop,	GTK_STOCK_MEDIA_STOP,		N_("_Stop"),			NULL),
+  CB(NextTrack,	GTK_STOCK_MEDIA_NEXT,		N_("_Next track"),		NULL),
 };
 #undef CB
 
@@ -417,6 +418,7 @@ typedef enum {
   TOGGLE_DEINTERLACE,
   TOGGLE_VIDEO_PP,
   TOGGLE_AUDIO_PP,
+  TOGGLE_UNBLANK,
 } toggle_actions_e;
 static GtkToggleActionEntry toggle_actions[] = {
   CB(Fullscreen,	NULL, N_("_Full-screen mode"),		"<control>F",	FALSE),
@@ -428,11 +430,14 @@ static GtkToggleActionEntry toggle_actions[] = {
   CB(Deinterlace,	NULL, N_("_Deinterlace"),		"<control>I",	FALSE),
   CB(VideoPP,		NULL, N_("_Post-processing"),		NULL,		FALSE),
   CB(AudioPP,		NULL, N_("_Post-processing"),		NULL,		FALSE),
+  CB(WMUnblank,		NULL, N_("Prevent _blanking in windowed mode"), NULL,	FALSE),
+  CB(FSSticky,		NULL, N_("Force _stickiness in full-screen mode"), NULL,	FALSE),
 };
 static const char *const toggle_prefs[] = {
-  NULL, NULL, NULL, NULL, NULL,
-  "gui.magnify_lowres_video", "gui.post_plugins.deinterlace_enable",
+  NULL, NULL, NULL, NULL, "gui.windowed_mode.auto_resize",
+  "gui.windowed_mode.magnify_lowres_video", "gui.post_plugins.deinterlace_enable",
   "gui.post_plugins.video_enable", "gui.post_plugins.audio_enable",
+  "gui.windowed_mode.unblank", "gui.fullscreen_mode.always_sticky",
 };
 #undef CB
 
@@ -462,10 +467,7 @@ vis_actions[] = {
   { "VisNone",		NULL, N_("_None"),	NULL, NULL, 0 },
 },
 subtitle_actions[] = {
-  { "SubtitlesOther",	NULL, "",		NULL, NULL, -3 },
-  /* Subtitles menu text */
-  { "SubtitlesNone",	NULL, N_("_None"),	NULL, NULL, -2 },
-  { "SubtitlesAuto",	NULL, N_("_Auto"),	NULL, NULL, -1 },
+  /* menu item order is relied upon in player.c:set_subtitles() */
   { "Subtitles0",	NULL, N_("Channel _0"),	NULL, NULL, 0 },
   { "Subtitles1",	NULL, N_("Channel _1"),	NULL, NULL, 1 },
   { "Subtitles2",	NULL, N_("Channel _2"),	NULL, NULL, 2 },
@@ -482,6 +484,11 @@ subtitle_actions[] = {
   { "Subtitles13",	NULL, N_("Channel 13"),	NULL, NULL, 13 },
   { "Subtitles14",	NULL, N_("Channel 14"),	NULL, NULL, 14 },
   { "Subtitles15",	NULL, N_("Channel 15"),	NULL, NULL, 15 },
+  /* Subtitles menu text */
+  { "SubtitlesNone",	NULL, N_("_None"),	NULL, NULL, -2 },
+  { "SubtitlesAuto",	NULL, N_("_Auto"),	NULL, NULL, -1 },
+  /* Other subtitle channels */
+  { "SubtitlesOther",	NULL, "",		NULL, NULL, -3 },
 };
 
 static GtkWidget *add_menu_ui (GtkUIManager *ui, int i)
@@ -496,7 +503,13 @@ static GtkWidget *add_menu_ui (GtkUIManager *ui, int i)
 	   "<menuitem action='Prefs' />\n"
 	   "<menuitem action='Keys' />\n"
 	   "<menuitem action='Startup' />\n"
+	   "<separator />\n"
+	   /* the next 3 items duplicate items in the video & audio menus */
+	   "<menuitem action='DeinterlaceConf' />\n"
+	   "<menuitem action='VideoPPConf' />\n"
+	   "<menuitem action='AudioPPConf' />\n"
 #ifdef HAVE_LIRC
+	   "<separator />\n"
 	   "<menuitem action='ReloadLIRC' />\n"
 #endif
 	   "<separator />\n"
@@ -510,6 +523,8 @@ static GtkWidget *add_menu_ui (GtkUIManager *ui, int i)
 	"</menu>\n"
 	"<menu action='ViewMenu'>\n"
 	  "<menuitem action='Fullscreen' />\n"
+	  "<menuitem action='HideMain' />\n"
+	  "<menuitem action='ShowMain' />\n"
 	  "<menu action='ToolbarMenu'>\n"
 	    "<menuitem action='WMToolbarVisible' />\n"
 	    "<menuitem action='WMToolbarSnap' />\n"
@@ -547,7 +562,6 @@ static GtkWidget *add_menu_ui (GtkUIManager *ui, int i)
 	    "<menuitem action='VisNone' />\n"
 	    "<placeholder name='VisItems' />\n"
 	  "</menu>\n"
-	  "<separator />\n"
 	  "<menu action='SubsMenu'>\n"
 	    "<menuitem action='SubtitlesAuto' />\n"
 	    "<menuitem action='SubtitlesNone' />\n"
@@ -568,6 +582,10 @@ static GtkWidget *add_menu_ui (GtkUIManager *ui, int i)
 	    "<menuitem action='Subtitles14' />\n"
 	    "<menuitem action='Subtitles15' />\n"
 	  "</menu>\n"
+	  "<menu action='ViewMisc'>\n"
+	    "<menuitem action='WMUnblank' />\n"
+	    "<menuitem action='FSSticky' />\n"
+	  "</menu>\n"
 	  "<separator />\n"
 	  "<menuitem action='EngineLog' />\n"
 	  "<menuitem action='JSConsole' />\n"
@@ -634,7 +652,9 @@ GtkAction *find_video_size_action (gdouble factor)
 
 void scale_changed_cb (GtkWidget *widget, gdouble factor, gpointer data)
 {
-  if (factor != -1 && action_items.resize_factor)
+  if (factor != -1 && action_items.resize_factor
+      && xine_get_status (stream) != XINE_STATUS_IDLE
+      && GTK_WIDGET_VISIBLE (gtv))
   {
     logprintf ("gxine: received scale change event (%lf%%)\n", factor);
     GtkAction *action = find_video_size_action (factor);
@@ -654,7 +674,7 @@ void scale_changed_cb (GtkWidget *widget, gdouble factor, gpointer data)
     foreach_glist (changed, gtk_radio_action_get_group
 			      (GTK_RADIO_ACTION (action_items.resize_factor)))
       if (g_signal_handlers_block_by_func (changed->data, js_Window_cb, NULL))
-        break;
+	break;
     g_object_set ((GObject *)action_items.resize_factor,
 		  "value", (gint)(factor * 1e+6), NULL);
     gtk_action_set_visible ((GtkAction *)action_items.resize_factor, TRUE);
@@ -667,6 +687,45 @@ void scale_changed_cb (GtkWidget *widget, gdouble factor, gpointer data)
     logprintf ("gxine: ignored scale change event (%lf%%)\n", factor);
 }
 
+static void update_subtitles_menu_internal (GtkActionGroup *action)
+{
+  if (!action)
+    return;
+  int i;
+  for (i = 0; i < 16; ++i)
+  {
+    static char subt[] = "Subtitles..";
+    char lang[XINE_LANG_MAX];
+    sprintf (subt + 9, "%d", i);
+    GtkAction *item = get_action (subt);
+    if (!item)
+      break;
+    char *label = NULL, *base = gettext (subtitle_actions[i].label);
+    if (xine_get_spu_lang (stream, i, lang))
+    {
+      label = base - 1;
+      while (*++label == ' ')
+	/* skip spaces */;
+      label = g_strconcat (label, strcmp (lang, "none") ? " / " : NULL, lang, NULL);
+    }
+    g_object_set ((GObject *) item, "label", label ? label : base, NULL);
+    free (label);
+  }
+}
+
+static gboolean subs_menu_cb (GtkWidget *widget, GdkEventExpose *event,
+			      gpointer action)
+{
+  update_subtitles_menu_internal (action);
+  return FALSE;
+}
+
+void update_subtitles_menu (void)
+{
+  if (ui)
+    update_subtitles_menu_internal (ui_get_action_group (ui));
+}
+
 void create_menus (GtkWidget *window)
 {
   GtkActionGroup *action;
@@ -683,10 +742,10 @@ void create_menus (GtkWidget *window)
 	xine_config_lookup_entry (xine, toggle_prefs[i], &entry))
       toggle_actions[i].is_active = entry.num_value;
 
-  if (!xine_config_lookup_entry (xine, "gui.fullscreen_toolbar", &entry))
+  if (!xine_config_lookup_entry (xine, "gui.fullscreen_mode.toolbar", &entry))
     entry.num_value = 0;
   toggle_actions[TOGGLE_FULLSCREEN_TOOLBAR].is_active = (entry.num_value >> 1) & 1;
-    
+
 #define AG(group) (group), G_N_ELEMENTS((group))
   gtk_action_group_add_actions (action, AG(main_actions), NULL);
   gtk_action_group_add_toggle_actions (action, AG(toggle_actions), NULL);
@@ -728,6 +787,8 @@ void create_menus (GtkWidget *window)
   action_items.fs_toolbar = get_toggle ("FSToolbarVisible");
   action_items.wm_toolbar = get_toggle ("WMToolbarVisible");
   action_items.wm_toolbar_snap = get_toggle ("WMToolbarSnap");
+  action_items.wm_unblank = get_toggle ("WMUnblank");
+  action_items.fs_sticky = get_toggle ("FSSticky");
 
   action_items.aspect = get_radio_group ("AspectAuto");
   action_items.vis = get_radio_group ("VisNone");
@@ -736,12 +797,22 @@ void create_menus (GtkWidget *window)
   action_items.subtitles = get_radio_group ("Subtitles0");
 
   action_items.keypad = get_action ("Keypad");
+  action_items.hidemain = get_action ("HideMain");
+  action_items.showmain = get_action ("ShowMain");
+  gtk_action_set_visible (action_items.showmain, FALSE);
 
-  if (xine_config_lookup_entry (xine, "gui.windowedmode_separate_toolbar",
+  if (xine_config_lookup_entry (xine, "gui.windowed_mode.separate_toolbar",
 				&entry)
       && !entry.num_value)
   {
     gtk_action_set_sensitive (&action_items.wm_toolbar->parent, FALSE);
     gtk_action_set_sensitive (&action_items.wm_toolbar_snap->parent, FALSE);
   }
+
+  GSList *proxy = gtk_action_get_proxies (get_action ("SubsMenu"));
+  while (proxy)
+  {
+    g_signal_connect (proxy->data, "event", (GCallback) subs_menu_cb, action);
+    proxy = g_slist_next (proxy);
+  }
 }
