@@ -249,6 +249,7 @@ static __attribute__ ((noreturn)) void *play_exec (void *data)
   free (mrl);
   pthread_cleanup_pop (TRUE);
   /*pthread_mutex_unlock (&engine_lock);*/
+  play_thread = 0;
   pthread_exit (NULL);
 }
 
@@ -289,12 +290,18 @@ void player_launch (const char *title, const char *mrl,
 
 void player_wait (void)
 {
-  pthread_join (play_thread, NULL);
+  pthread_t thread = play_thread;
+  play_thread = 0;
+  if (thread)
+    pthread_join (thread, NULL);
 }
 
 void player_stop (void)
 {
-  pthread_cancel (play_thread);
+  pthread_t thread = play_thread;
+  play_thread = 0;
+  if (thread)
+    pthread_cancel (thread);
   xine_stop (stream);
 }
 
@@ -360,13 +367,13 @@ static void set_subtitles (int sub)
     if (count > sub + 3)
     {
       if (sub < 0)
-        count = 1; /* for None, Auto */
+	count = 1; /* for None, Auto */
       while (menuitem && --count > sub)
 	menuitem = menuitem->next;
       if (menuitem)
       {
-        gtk_action_activate (menuitem->data);
-        return;
+	gtk_action_activate (menuitem->data);
+	return;
       }
     }
     /* not in menu */
@@ -974,7 +981,7 @@ static JSBool controls_play (JSContext *cx, JSObject *obj, uintN argc,
 	{
 	  gtk_video_unblank_screen ((GtkVideo *)gtv);
 	  xine_play (stream, pos < 0 ? 0 : pos, pos_time < 0 ? 0 : pos_time);
-        }
+	}
 	break;
       }
       play_item_dispose (item);
@@ -990,7 +997,7 @@ static JSBool controls_play (JSContext *cx, JSObject *obj, uintN argc,
  * (Useful on some keyboards with CD/DVD control keys.)
  */
 static JSBool controls_play_pause (JSContext *cx, JSObject *obj, uintN argc,
-                                  jsval *argv, jsval *rval)
+				  jsval *argv, jsval *rval)
 {
   se_log_fncall_checkinit ("play_pause");
   se_argc_check_max (1, "play_pause");
@@ -1009,7 +1016,7 @@ static JSBool controls_play_pause (JSContext *cx, JSObject *obj, uintN argc,
 }
 
 static JSBool js_is_live_stream (JSContext *cx, JSObject *obj, uintN argc,
-                                 jsval *argv, jsval *rval)
+				 jsval *argv, jsval *rval)
 {
   *rval = JSVAL_FALSE;
 
@@ -1134,11 +1141,11 @@ void player_init (void)
        *     VARIABLE[=TYPE] or METHOD([PARAMETER TYPE,...])
        *   To the right, descriptive text
        */
-      { "av_speed", N_("v=int, min, max; playback speed"), 
-       UI_CUSTOM (get_speed, set_speed), 
-       XINE_SPEED_PAUSE, 
-       XINE_SPEED_FAST_4, 
-       FALSE, 
+      { "av_speed", N_("v=int, min, max; playback speed"),
+       UI_CUSTOM (get_speed, set_speed),
+       XINE_SPEED_PAUSE,
+       XINE_SPEED_FAST_4,
+       FALSE,
        { listen_speed } },
       { "vo_aspect", N_("v=int; aspect ratio"), UI_XINE_PARAM (XINE_PARAM_VO_ASPECT_RATIO, set_aspect), 0, XINE_VO_ASPECT_NUM_RATIOS - 1, TRUE },
       { "vo_subtitle", N_("v=int, min, max; subtitle channel"), UI_XINE_PARAM (XINE_PARAM_SPU_CHANNEL, set_subtitles), -2, GXINE_MAX_SPU_CHANNEL },
@@ -1162,7 +1169,9 @@ void player_init (void)
       { NULL }
     };
     static const ui_property_t fs_subprops[] = {
-      { "sticky", N_("v=bool, toggle(); forced stickiness in full-screen mode"), UI_BOOL (fs_sticky, fs_always_sticky, NULL) },
+      { "sticky", NULL, UI_BOOL (fs_sticky, fs_always_sticky, NULL) },
+	/* ↑ deprecated; it's really just gui.fullscreen_mode.always_sticky */
+      { "is_sticky", N_("v=bool, toggle(); forced stickiness in full-screen mode"), UI_BOOL (fs_sticky, fs_is_sticky, window_fs_stickiness_update) },
       { NULL }
     };
 
@@ -1196,7 +1205,7 @@ void player_init (void)
       { "has_time", has_time, 0, 0,
 	SE_GROUP_ENGINE, NULL, N_("whether the stream has a time index") },
       { "pause", controls_pause, 0, 0,
-  	SE_GROUP_ENGINE, N_("[bool]"), NULL },
+	SE_GROUP_ENGINE, N_("[bool]"), NULL },
       { "stop", controls_stop, 0, 0,
 	SE_GROUP_ENGINE, NULL, NULL },
       { "eject", controls_eject, 0, 0,
@@ -1204,7 +1213,7 @@ void player_init (void)
       { "play_pause", controls_play_pause, 0, 0,
 	SE_GROUP_ENGINE, N_("[bool]"), NULL },
       { "snapshot", js_snapshot, 0, 0,
-        /* these correspond to the options in the snapshot-save dialogue box */
+	/* these correspond to the options in the snapshot-save dialogue box */
 	SE_GROUP_ENGINE, N_("[file name [, scale, blend]]"), NULL },
 
       { "set_video_size", js_set_video_size, 0, 0,
@@ -1268,7 +1277,7 @@ void player_init (void)
        _("Double the size of small video streams"),
        _("This affects video streams whose dimensions are at most ⅓ "
 	 "of those of the display."),
-       0, GXINE_TRUE, NULL);       
+       0, GXINE_TRUE, NULL);
     config_update_default ("gui.windowed_mode.magnify_lowres_video", 1);
     xine_config_register_bool
       (xine, "gui.windowed_mode.auto_resize", 1,
