@@ -55,6 +55,7 @@
 #include "engine.h"
 #include "player.h"
 #include "drag_drop.h"
+#include "gtkvideo.h"
 
 /*
 #define LOG
@@ -470,7 +471,7 @@ static int playlist_load (const char *fname)
 
       if (!strcasecmp (node->name, "SETTINGS"))
       {
-        /* gxine-specific */
+	/* gxine-specific */
 	gtk_toggle_button_set_active
 	  (random_button, xml_parser_get_property_bool (node, "RANDOM", 0));
 	gtk_toggle_button_set_active
@@ -551,7 +552,7 @@ void playlist_save (char *file)
 
     fprintf
       (f, "<ASX VERSION=\"3.0\">\n"
-          "  <SETTINGS REPEAT='%s' REPEAT-TRACK='%s' RANDOM='%s'/>\n",
+	  "  <SETTINGS REPEAT='%s' REPEAT-TRACK='%s' RANDOM='%s'/>\n",
        tf[!!gtk_toggle_button_get_active (repeat_button)],
        tf[!!gtk_toggle_button_get_active (repeat_track_button)],
        tf[!!gtk_toggle_button_get_active (random_button)]);
@@ -613,7 +614,7 @@ play_item_t *playlist_get_item (int pos)
       ((pos = playlist_clip (pos)) >= 0 /* nth item */
        && gtk_tree_model_iter_nth_child (pl_model, &iter, NULL, pos)))
     return peek_play_item (&iter);
-    
+
   else
     return NULL;
 }
@@ -702,7 +703,7 @@ static gint playlist_add_int (const char *mrl, gint ins_pos)
   if (ins_pos < 0)
     for (i = 0; i < playlist_size (); ++i)
       if (!strcmp (playlist_get_item (i)->mrl, mrl))
-        return i;
+	return i;
 
   play_item = play_item_new (NULL, mrl, 0, 0);
   play_item_check_autoplay (play_item);
@@ -885,12 +886,12 @@ playlist_load_generic (const char *mrl, gint ins_pos,
       }
 
       if (ins_pos < 0)
-        ins_pos = playlist_add (item, -1);
+	ins_pos = playlist_add (item, -1);
       else
-        playlist_add (item, ins_pos);
+	playlist_add (item, ins_pos);
 
       if (retval == -1)
-        retval = ins_pos;
+	retval = ins_pos;
 
       ++ins_pos;
       ++index;
@@ -948,8 +949,8 @@ pl_smil_fetch (pl_xml_info_t *info, void *data)
       {
 	if (!info->node->child)
 	  continue;
-        info->data = 2;
-        pl_push (info);
+	info->data = 2;
+	pl_push (info);
       }
 
     case 2: /* SWITCH */
@@ -1191,10 +1192,10 @@ static int playlist_load_asx (const char *mrl, gint ins_pos)
       /* look for mms:// in a line */
       if (strstr(lines[i], "mms://"))
       {
-        remove_trailing_cr (lines[i]);
-        /* add to playlist */
+	remove_trailing_cr (lines[i]);
+	/* add to playlist */
 	if (ret >= 0)
-          playlist_add_mrl (strstr(lines[i], "mms://"), ins_pos);
+	  playlist_add_mrl (strstr(lines[i], "mms://"), ins_pos);
 	else
 	  ret = playlist_add_mrl (strstr(lines[i], "mms://"), ins_pos);
       }
@@ -1558,13 +1559,46 @@ static int has_been_played (int pos)
   return playlist_get_item (pos)->played;
 }
 
+static int is_ignored (int pos)
+{
+  return playlist_get_item (pos)->ignore;
+}
+
+static int select_next_random (void)
+{
+  int pos = rand() % playlist_size();
+  int count = 0;
+  const int size = playlist_size ();
+  while (count < size && has_been_played (pos))
+  {
+    pos = (pos + 1) % size;
+    count++;
+  }
+  return has_been_played (cur_list_pos) ? size + 1 : pos;
+}
+
+static int select_next_linear (int pos)
+{
+  int count = 0;
+  const int size = playlist_size ();
+  while (count < size && is_ignored (pos))
+  {
+    pos = (pos + 1) % size;
+    count++;
+  }
+  return is_ignored (cur_list_pos) ? size + 1 : pos;
+}
+
 static void play_next (void)
 {
   int is_repeat, is_random;
 
   if (gtk_toggle_button_get_active (repeat_track_button))
   {
-    playlist_play (cur_list_pos);
+    if (!is_ignored (cur_list_pos))
+      playlist_play (cur_list_pos);
+    else
+      playlist_logo (NULL);
     return;
   }
 
@@ -1574,20 +1608,8 @@ static void play_next (void)
   unmark_play_item ();
   ref_list_pos = -1;
 
-  if (is_random)
-  {
-    cur_list_pos = rand() % playlist_size();
-    int count = 0;
-    while ((count<playlist_size()) && has_been_played (cur_list_pos))
-    {
-      cur_list_pos = (cur_list_pos + 1) % playlist_size();
-      count++;
-    }
-
-    if (has_been_played (cur_list_pos))
-      cur_list_pos = playlist_size()+1;
-  } else
-    cur_list_pos++;
+  cur_list_pos = is_random ? select_next_random ()
+			   : select_next_linear (cur_list_pos + 1);
 
   if (is_repeat && (cur_list_pos>=playlist_size()))
   {
@@ -1599,12 +1621,12 @@ static void play_next (void)
       {
 	play_item_t *item;
 	item = playlist_get_item (i);
-	item->played = 0;
+	item->played = item->ignore;
       }
 
-      cur_list_pos = rand() % playlist_size();
+      cur_list_pos = select_next_random ();
     } else
-      cur_list_pos = 0;
+      cur_list_pos = select_next_linear (0);
   }
 
   if (cur_list_pos<playlist_size())
@@ -1623,17 +1645,25 @@ static void play_next (void)
 }
 
 #ifdef XINE_MSG_AUTHENTICATION_NEEDED
-static gboolean auth_validate (const char *text)
+static char *auth_escape (GtkEntry *entry)
 {
-  if (!text || !*text)
-    return FALSE;
+  const char *text = gtk_entry_get_text (entry);
+  char *dest = malloc (strlen (text) * 3 + 1);
+  char *ptr = dest;
+
   while (*text)
   {
     unsigned char c = (unsigned char) *text++;
-    if (c < 33 || c == '/' || c == ':' || c == '@')
-      return FALSE;
+    if (c < 33 || c == '/' || c == ':' || c == '@' || c > '~')
+    {
+      sprintf (ptr, "%%%02X", c);
+      ptr += 3;
+    }
+    else
+      *ptr++ = c;
   }
-  return TRUE;
+  *ptr = 0;
+  return dest;
 }
 
 static int display_auth (int args, const char *mrl)
@@ -1657,24 +1687,19 @@ static int display_auth (int args, const char *mrl)
 
   if (gtk_dialog_run (auth.dbox) == GTK_RESPONSE_OK)
   {
-    const char *name = gtk_entry_get_text (auth.name);
-    const char *pass = gtk_entry_get_text (auth.pass);
-    if (!auth_validate (name) || !auth_validate (pass))
-    {
-      display_error (FROM_GXINE, "%s", _("Authentication data contains invalid characters."));
-      goto ret;
-    }
+    char *name = auth_escape (auth.name);
+    char *pass = auth_escape (auth.pass);
 
     host += 3;
     const char *at = strchr (host, '@');
-    const char *slash = strchr (host, ':');
+    const char *slash = strchr (host, '/');
     if (at && slash && at > slash)
       at = NULL;
     if (at)
     {
       const char *colon = strchr (host, ':');
       if (colon >= at)
-        at = NULL;
+	at = NULL;
     }
 
     if (at)
@@ -1682,6 +1707,9 @@ static int display_auth (int args, const char *mrl)
     else
       txt = g_strdup_printf ("%.*s%s:%s@%s", (int)(host - mrl), mrl, name, pass, host);
 
+    free (name);
+    free (pass);
+
     play_item_t *play_item;
     int pos;
     for (pos = 0; pos < playlist_size (); ++pos)
@@ -1703,6 +1731,17 @@ static int display_auth (int args, const char *mrl)
     playlist_play (pos);
     retval = 1;
   }
+  else
+  {
+    play_item_t *play_item;
+    int pos;
+    for (pos = 0; pos < playlist_size (); ++pos)
+      if (!strcmp ((play_item = playlist_get_item (pos))->mrl, mrl))
+      {
+	play_item->played = play_item->ignore = TRUE;
+	break;
+      }
+  }
 
 ret:
   gtk_widget_hide ((GtkWidget *) auth.dbox);
@@ -1780,6 +1819,12 @@ static void xine_event_cb (void *user_data, const xine_event_t *event)
     gdk_threads_leave();
     break;
 
+  case XINE_EVENT_SPU_BUTTON:
+    {
+      xine_spu_button_t *btn = event->data;
+      gtk_video_in_spu_button (gtv, btn->direction);
+    }
+
 #ifndef XINE_EVENT_MRL_REFERENCE_EXT
 /* present in 1.1.0 but not 1.0.2 */
 #define XINE_EVENT_MRL_REFERENCE_EXT 13
@@ -1870,38 +1915,39 @@ typedef struct {
       switch (data->type)
       {
       default:
-        g_print (_("xine_event_cb: unknown XINE_MSG_*\n"));
+	g_print (_("xine_event_cb: unknown XINE_MSG_*\n"));
       case XINE_MSG_NO_ERROR:
       case XINE_MSG_AUDIO_OUT_UNAVAILABLE:
-        msg = display_info;
-        break;
-      
+	msg = display_info;
+	break;
+
       case XINE_MSG_ENCRYPTED_SOURCE:
-        msg = display_info_combinable;
-        break;
+	msg = display_info_combinable;
+	break;
 
       case XINE_MSG_GENERAL_WARNING:
       case XINE_MSG_NETWORK_UNREACHABLE:
-        msg = display_warning;
-        break;
+	msg = display_warning;
+	break;
 
       case 13 /* UNCOMMENTME: XINE_MSG_FILE_EMPTY */:
-        fallback = _("File is empty:"); /* missing in xine-lib < 1.1.2 */
+	fallback = _("File is empty:"); /* missing in xine-lib < 1.1.2 */
       case XINE_MSG_UNKNOWN_HOST:
-        msg = display_warning_combinable;
-        break;
+	msg = display_warning_combinable;
+	break;
 
       case XINE_MSG_LIBRARY_LOAD_ERROR:
       case XINE_MSG_SECURITY:
       case XINE_MSG_UNKNOWN_DEVICE:
-        msg = display_error;
-        break;
+	msg = display_error;
+	break;
 
       case XINE_MSG_READ_ERROR:
       case XINE_MSG_CONNECTION_REFUSED:
       case XINE_MSG_FILE_NOT_FOUND:
       case XINE_MSG_PERMISSION_ERROR:
-        msg = display_error_combinable;
+	msg = display_error_combinable;
+	break;
 
 #ifdef XINE_MSG_AUTHENTICATION_NEEDED
       /* new in xine-lib 1.2 */
@@ -1929,7 +1975,7 @@ typedef struct {
 	/**/;
       else if (data->num_parameters)
       {
-        int i;
+	int i;
 	const char *param = (char *)data + data->parameters;
 	char *txt = strdup ("");
 	for (i = 0; i < data->num_parameters; ++i)
@@ -2338,7 +2384,7 @@ static const char buttons_structure[] =
       "<menuitem action='prev' />\n"
       "<menuitem action='next' />\n"
     "</popup>\n"
-  "</ui>"; 
+  "</ui>";
 
 static void sel_changed_cb (GtkTreeSelection *sel, gpointer data)
 {
