@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2006 the xine-project
+ * Copyright (C) 2004-2007 the xine-project
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,8 +16,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: post.c,v 1.45 2006/04/09 14:27:29 dsalt Exp $
- *
  * post-plugin handling
  */
 
@@ -279,7 +277,7 @@ post_make_parameter_string (const gxine_post_t *info)
     {
     case POST_PARAM_TYPE_INT:
       if (param->enum_values)
-        asreprintf
+	asreprintf
 	  (&new_paramstr, "%s,%s=%s", new_paramstr, param->name,
 	   param->enum_values[*(int *) (info->params + param->offset)]);
       else
@@ -507,14 +505,14 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
 				 GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
 				 GTK_STOCK_OK, GTK_RESPONSE_OK,
 				 NULL);
+  GtkDialog *dbox = GTK_DIALOG (info->dbox);
   g_signal_connect (G_OBJECT(info->dbox), "response",
 		    G_CALLBACK(post_config_post_response), info);
-  gtk_dialog_set_default_response (GTK_DIALOG (info->dbox), GTK_RESPONSE_OK);
+  gtk_dialog_set_default_response (dbox, GTK_RESPONSE_OK);
   ui_add_undo_response (info->dbox, NULL);
   free (title);
   table = gtk_table_new (1, 2, FALSE);
-  gtk_box_pack_start (GTK_BOX(GTK_DIALOG(info->dbox)->vbox), table,
-		      FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX(dbox->vbox), table, FALSE, TRUE, 0);
 
   info->params = post_parse_parameters (info->plugin, info->parameters);
   param = param_desc->parameter - 1;
@@ -543,10 +541,7 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
       {
 	GtkObject *adj =
 	  gtk_adjustment_new (*(int *)param_p, INT_MIN, INT_MAX, 1, 10, 0);
-	widget = gtk_spin_button_new (GTK_ADJUSTMENT(adj), 1, 0);
-	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON(widget),
-					   GTK_UPDATE_ALWAYS);
-	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON(widget), TRUE);
+	widget = ui_spin_button_new (adj);
 	g_signal_connect (G_OBJECT(widget), "value-changed",
 			  G_CALLBACK(spin_cb), param_p);
       }
@@ -564,11 +559,8 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
 	adj = gtk_adjustment_new (*(double *)param_p,
 				  param->range_min, param->range_max,
 				  step, page, 0);
-	widget = gtk_hscale_new (GTK_ADJUSTMENT(adj));
+	widget = ui_hscale_new (adj, GTK_POS_TOP, floating ? 2 : 0);
 	gtk_widget_set_size_request (widget, 100, -1);
-	gtk_scale_set_draw_value (GTK_SCALE(widget), TRUE);
-	gtk_scale_set_value_pos (GTK_SCALE(widget), GTK_POS_TOP);
-	gtk_scale_set_digits (GTK_SCALE(widget), floating ? 2 : 0); /* hmm... */
 	g_signal_connect (G_OBJECT (adj), "value-changed",
 			  G_CALLBACK (range_cb), param_p);
       }
@@ -607,8 +599,7 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
     if (param->description)
       gtk_tooltips_set_tip (tips, widget, param->description, NULL);
 
-    widget = gtk_label_new (param->name);
-    gtk_misc_set_alignment (GTK_MISC (widget), 1, 0.5);
+    widget = ui_label_new_with_xalign (param->name, 1);
     gtk_table_attach (GTK_TABLE(table), widget,
 		      0, 1, param_count, param_count + 1,
 		      GTK_FILL, GTK_FILL, 2, 2);
@@ -679,12 +670,11 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
 				      GTK_POLICY_AUTOMATIC);
 
       gtk_widget_set_size_request (window, 1, -1);
-      gtk_box_pack_end (GTK_BOX(GTK_DIALOG(info->dbox)->vbox), window,
-			TRUE, TRUE, 2);
+      gtk_box_pack_end (GTK_BOX(dbox->vbox), window, TRUE, TRUE, 2);
     }
     free (helptext);
 
-    gtk_box_pack_end (GTK_BOX(GTK_DIALOG(info->dbox)->vbox),
+    gtk_box_pack_end (GTK_BOX(dbox->vbox),
 		      gtk_hseparator_new (), FALSE, TRUE, 2);
   }
 
@@ -695,7 +685,7 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
     GdkGeometry geom;
     geom.width_inc = 0;
     geom.height_inc = 1;
-    gtk_window_set_geometry_hints (GTK_WINDOW(info->dbox), info->dbox, &geom,
+    gtk_window_set_geometry_hints (GTK_WINDOW(dbox), info->dbox, &geom,
 				   GDK_HINT_RESIZE_INC);
   }
 
@@ -789,9 +779,9 @@ post_config_post_chain_set_plugin (GtkOptionMenu *menu, gxine_post_t *info)
 	  break;
       if (chain->names[i])
       {
-        reset_pp_t *info = malloc (sizeof (reset_pp_t));
-        info->menu = menu;
-        info->index = i;
+	reset_pp_t *info = malloc (sizeof (reset_pp_t));
+	info->menu = menu;
+	info->index = i;
 	g_idle_add (reset_pp, info);
       }
     }
@@ -890,11 +880,13 @@ post_config_post_add_plugin (gxine_chain_t *chain, xine_post_t *post,
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), enabled);
   gtk_box_pack_start (GTK_BOX(info->box), w, FALSE, TRUE, 0);
 
+  GtkBox *box = GTK_BOX (info->box);
+
   /* FIXME but not until combo box menu items can have tooltips */
   w = gtk_option_menu_new ();
   gtk_option_menu_set_menu (GTK_OPTION_MENU(w), m);
   gtk_option_menu_set_history (GTK_OPTION_MENU(w), history);
-  gtk_box_pack_start_defaults (GTK_BOX(info->box), w);
+  gtk_box_pack_start_defaults (box, w);
   g_signal_connect (G_OBJECT(w), "changed",
 		    G_CALLBACK(post_config_post_chain_set_plugin), info);
   if (hist_desc)
@@ -902,18 +894,18 @@ post_config_post_add_plugin (gxine_chain_t *chain, xine_post_t *post,
 
   info->up = w = ui_button_new_stock (GTK_STOCK_GO_UP);
   gtk_widget_set_sensitive (w, !!chain->plugins); /* disable for first plugin */
-  gtk_box_pack_end (GTK_BOX(info->box), w, FALSE, TRUE, 0);
+  gtk_box_pack_end (box, w, FALSE, TRUE, 0);
   g_signal_connect (G_OBJECT(w), "clicked",
 		    G_CALLBACK(post_config_post_chain_move_plugin), info);
 
   w = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
-  gtk_box_pack_end (GTK_BOX(info->box), w, FALSE, TRUE, 0);
+  gtk_box_pack_end (box, w, FALSE, TRUE, 0);
   g_signal_connect (G_OBJECT(w), "clicked",
 		    G_CALLBACK(post_config_post_chain_delete_plugin), info);
 
   info->pref = w = gtk_toggle_button_new_with_label (GTK_STOCK_PROPERTIES);
   g_object_set (G_OBJECT(w), "use-stock", TRUE, NULL);
-  gtk_box_pack_end (GTK_BOX(info->box), w, FALSE, TRUE, 0);
+  gtk_box_pack_end (box, w, FALSE, TRUE, 0);
   if (!xine_post_input (post, "parameters"))
     gtk_widget_set_sensitive (w, FALSE);
   info->pref_toggled = g_signal_connect (G_OBJECT(w), "toggled",
