@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 the xine-project
+ * Copyright (C) 2004-2006 the xine-project
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,12 +16,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: post.h,v 1.6 2006-02-21 19:06:12 dsalt Exp $
- *
  * post-plugin handling
  */
 
-#ifndef HAVE_POST_H
+#ifndef GXINE_POST_H
+#define GXINE_POST_H
 
 #include <xine.h>
 
