@@ -44,6 +44,9 @@
 
 #include <jsapi.h>
 
+#if defined(WITH_GUDEV) || defined(WITH_HAL)
+# define GXINE_DEVICE_INFO
+#endif
 
 typedef struct {
   void *notebook; /* NULL - get from parent */
@@ -105,14 +108,14 @@ static int select_show_prefs_internal (GNode *page, int exp)
       void (*func)(GtkWidget *);
       if (pref->exp <= exp)
       {
-        func = gtk_widget_show;
-        state |= 1;
-        last = pref;
+	func = gtk_widget_show;
+	state |= 1;
+	last = pref;
       }
       else
       {
-        func = gtk_widget_hide;
-        state |= 2;
+	func = gtk_widget_hide;
+	state |= 2;
       }
       if (pref->exp <= exp)
 	last = pref;
@@ -290,7 +293,100 @@ static void enum_cb (GtkWidget* widget, gpointer data)
   }
 }
 
-#ifdef WITH_HAL
+#ifdef WITH_GUDEV
+#define G_UDEV_API_IS_SUBJECT_TO_CHANGE
+#include <gudev/gudev.h>
+
+static GUdevClient *gudev = NULL;
+
+static gboolean check_gudev (void)
+{
+  static const gchar *const subsystems[] = { NULL }; /* at least DVB & block */
+  if (!gudev)
+    gudev = g_udev_client_new (subsystems);
+  return !!gudev;
+}
+
+static char *
+get_gudev_property (const char *name, const char *property, const char *sysfs)
+{
+  GUdevDevice *dev = g_udev_client_query_by_device_file (gudev, name);
+  const gchar *prop;
+  char *ret;
+
+  if (!dev)
+    return NULL;
+
+  prop = property ? g_udev_device_get_property (dev, property) : NULL;
+  if (prop && prop[0])
+  {
+    /* g_strcompress doesn't handle "\xNN" */
+    char *ptr = ret = malloc (strlen (prop) + 1);
+    char c;
+    while ((c = *prop++))
+    {
+      if (c == '\\')
+      {
+	char tmp[] = { '0', prop[0], prop[1], prop[2], 0 };
+	prop += 3;
+	c = (char) strtol (tmp, NULL, 0);
+      }
+      *ptr++ = c;
+    }
+    *ptr = 0;
+  }
+  else
+  {
+    prop = sysfs ? g_udev_device_get_sysfs_attr (dev, sysfs) : NULL;
+    ret = (prop && prop[0]) ? strdup (prop) : NULL;
+  }
+
+  g_object_unref ((GObject *)dev);
+
+  return ret;
+}
+
+static char *
+get_hal_device_info (const char *dev)
+{
+  if (!check_gudev () || !dev)
+    return NULL;
+
+  int ldev = strlen (dev);
+  char buf[FILENAME_MAX + ldev + 1];
+  strcpy (buf, dev); /* safe! */
+  if (buf[0] == '/')
+  {
+    ldev = strrchr (buf, '/') - buf + 1;
+    int tmp = readlink (dev, buf + ldev, FILENAME_MAX - 1);
+    if (tmp <= 0)
+      strcpy (buf, dev); /* safe! */
+    else if (buf[ldev] == '/')
+    {
+      memmove (buf, buf + ldev, tmp);
+      buf[tmp] = 0;
+    }
+    else
+    {
+      char *p;
+      buf[ldev + tmp] = 0;
+      while ((p = strstr (buf, "//")))
+	memmove (p, p + 1, strlen (p));
+      while ((p = strstr (buf, "/./")))
+	memmove (p, p + 2, strlen (p) - 1);
+      while ((p = strstr (buf, "/../")))
+      {
+	char *q = p;
+	while (--q >= buf && *q != '/')
+	  /**/;
+	memmove (q, p + 3, strlen (p) - 2);
+      }
+    }
+  }
+
+  return get_gudev_property (buf, "ID_MODEL_ENC", "name");
+}
+#elif defined(WITH_HAL)
 #include <unistd.h>
 #include <hal/libhal.h>
 
@@ -356,15 +452,15 @@ get_hal_device_info (const char *dev)
       char *p;
       buf[ldev + tmp] = 0;
       while ((p = strstr (buf, "//")))
-        memmove (p, p + 1, strlen (p));
+	memmove (p, p + 1, strlen (p));
       while ((p = strstr (buf, "/./")))
-        memmove (p, p + 2, strlen (p) - 1);
+	memmove (p, p + 2, strlen (p) - 1);
       while ((p = strstr (buf, "/../")))
       {
-        char *q = p;
-        while (--q >= buf && *q != '/')
-          /**/;
-        memmove (q, p + 3, strlen (p) - 2);
+	char *q = p;
+	while (--q >= buf && *q != '/')
+	  /**/;
+	memmove (q, p + 3, strlen (p) - 2);
       }
     }
   }
@@ -383,7 +479,9 @@ get_hal_device_info (const char *dev)
 	 /* FIXME - BSD etc. */
 	 ;
 }
+#endif /* WITH_HAL */
 
+#ifdef GXINE_DEVICE_INFO
 static void
 display_hal_device_info (GtkWidget *widget, const char *dev)
 {
@@ -397,7 +495,7 @@ display_hal_device_info (GtkWidget *widget, const char *dev)
     free (hal);
   }
 }
-#endif /* WITH_HAL */
+#endif /* WITH_GUDEV || WITH_HAL */
 
 static void file_cb (GtkWidget *widget, int response, gpointer data)
 {
@@ -418,9 +516,9 @@ static void file_cb (GtkWidget *widget, int response, gpointer data)
     logprintf ("preferences: updating entry\n");
     entry.str_value = key;
     xine_config_update_entry (xine, &entry);
-#ifdef WITH_HAL
+#ifdef GXINE_DEVICE_INFO
     if (entry.num_value == 2 /* XINE_CONFIG_STRING_IS_DEVICE_NAME */)
-      display_hal_device_info (data, key); 
+      display_hal_device_info (data, key);
 #endif
   }
   free (key);
@@ -431,7 +529,7 @@ static void file_activate_cb (GtkWidget *widget, gpointer data)
   file_cb (widget, GTK_RESPONSE_ACCEPT, data);
 }
 
-#ifdef WITH_HAL
+#ifdef GXINE_DEVICE_INFO
 static void file_preview_cb (GtkFileChooser *fc, gpointer data)
 {
   GtkLabel *info = GTK_LABEL (gtk_file_chooser_get_preview_widget (fc));
@@ -453,7 +551,7 @@ static void file_map_cb (GtkFileChooser *fcb, gpointer fc)
 			      G_CALLBACK(file_activate_cb), fc);
     g_object_set_data (fc, "gxine", fc);
   }
-#ifdef WITH_HAL
+#ifdef GXINE_DEVICE_INFO
   file_preview_cb (fcb, fc);
 #endif
 }
@@ -613,7 +711,7 @@ static GtkWidget *create_item_editable (const xine_cfg_entry_t *entry)
       }
       else
 	gtk_file_chooser_set_filename ((GtkFileChooser *) fc, entry->str_value);
-#ifdef WITH_HAL
+#ifdef GXINE_DEVICE_INFO
       gtk_file_chooser_set_use_preview_label ((GtkFileChooser *) fc, FALSE);
       GtkWidget *preview = g_object_new (GTK_TYPE_LABEL, "angle", 90.0,
 					 "selectable", FALSE, NULL);
@@ -622,7 +720,7 @@ static GtkWidget *create_item_editable (const xine_cfg_entry_t *entry)
       g_object_connect (G_OBJECT(fc),
 	"signal::response", G_CALLBACK(file_cb), widget,
 	"signal::file-activated", G_CALLBACK(file_activate_cb), widget,
-#ifdef WITH_HAL
+#ifdef GXINE_DEVICE_INFO
 	"signal::update-preview", G_CALLBACK(file_preview_cb), widget,
 	"signal::map", G_CALLBACK(file_preview_cb), fc,
 #endif
@@ -711,7 +809,7 @@ static GtkWidget *create_item_extra (const xine_cfg_entry_t *entry)
   switch (entry->type)
   {
   case XINE_CONFIG_TYPE_STRING:
-#ifdef WITH_HAL
+#ifdef GXINE_DEVICE_INFO
     if (entry->num_value == 2 /* XINE_CONFIG_STRING_IS_DEVICE_NAME */)
       return gtk_label_new (NULL);
 #endif
@@ -850,7 +948,7 @@ static gboolean focus_item_cb (GtkWidget *widget, GtkDirectionType *dir,
     gtk_adjustment_set_value (adj, top);
   else if (bottom + 4 > adj->value + viewport->allocation.height)
     gtk_adjustment_set_value (adj, bottom - viewport->allocation.height + 4);
-  
+
   return FALSE;
 }
 
@@ -910,7 +1008,7 @@ static gboolean put_content (GNode *node, gpointer data)
 			GTK_EXPAND | GTK_FILL, GTK_SHRINK, 2, 5);
       gtk_box_pack_start_defaults (box, pref->item.editable);
       gtk_box_pack_start_defaults (box, extra);
-#ifdef WITH_HAL
+#ifdef GXINE_DEVICE_INFO
       xine_cfg_entry_t entry;
       const char *key = g_object_get_data (G_OBJECT (pref->item.editable), "cfg");
       if (xine_config_lookup_entry (xine, key, &entry))
@@ -1094,7 +1192,7 @@ void preferences_update_entry (const xine_cfg_entry_t *entry)
       if (entry->num_value)
       {
 	gtk_file_chooser_set_filename (widget, entry->str_value);
-#ifdef WITH_HAL
+#ifdef GXINE_DEVICE_INFO
 	display_hal_device_info (widget, entry->str_value);
 #endif
       }
