@@ -35,12 +35,13 @@
 #include "globals.h"
 #include "engine.h"
 #include "server.h"
+#include "utils.h"
 
 /*
 #define LOG
 */
 
-#define SOCKET_FILENAME "%s/.gxine/socket"
+#define SOCKET_LEAFNAME	"socket"
 #define BUF_SIZE        1024
 
 static int       gxsocket;
@@ -154,11 +155,11 @@ static __attribute__ ((noreturn)) void *socket_listener (void *data)
 	default:
 	  if (errno)
 	    g_printerr (_("server: read error %d\n"), errno);
-          else
-        case ESPIPE:
-        case EPIPE:
+	  else
+	case ESPIPE:
+	case EPIPE:
 	case ECONNRESET:
-            g_print (_("server: client disconnected\n"));
+	    g_print (_("server: client disconnected\n"));
 	  listening = 0;
 	  break;
 	}
@@ -183,8 +184,7 @@ static __attribute__ ((noreturn)) void *socket_listener (void *data)
 
 void server_setup (void)
 {
-  char filename[FILENAME_MAX];
-  snprintf (filename, sizeof (filename), SOCKET_FILENAME, getenv ("HOME"));
+  char *filename = get_config_filename (SOCKET_LEAFNAME);
   if (strlen (filename) >= sizeof (((struct sockaddr_un *)0)->sun_path))
   {
     fputs (_("server: name too long - gxine_client will not be able to connect\n"),
@@ -193,6 +193,7 @@ void server_setup (void)
   }
   else
     gxsocket = make_socket (filename);
+  free (filename);
 }
 
 void server_start (void)
@@ -243,14 +244,13 @@ int server_client_connect (void)
     struct sockaddr s;
   } cli_adr = { .u = {0} }, serv_adr = { .u = {0} };
   int                length = sizeof(struct sockaddr_un);
-  char               filename[FILENAME_MAX];
 
   signal (SIGPIPE, sigpipe_handler);
 
   /* server filename */
-  snprintf (filename, sizeof (filename), SOCKET_FILENAME, getenv ("HOME"));
+  char *filename = get_config_filename (SOCKET_LEAFNAME);
   if (strlen (filename) >= sizeof (cli_adr.u.sun_path))
-    return 0; /* no point in printing anything... */
+    goto nothing; /* no point in printing anything... */
 
   logprintf ("server: trying to connect to already running instance of gxine (%s)...\n",
 	    filename);
@@ -268,7 +268,7 @@ int server_client_connect (void)
   if (bind (client_fd, &cli_adr.s, length) < 0)
   {
     perror ("bind");
-    return 0;
+    goto nothing;
   }
 
   /* initialize the server address structure */
@@ -279,13 +279,18 @@ int server_client_connect (void)
   {
     logperror ("connect");
     server_client_stop ();
-    return 0;
+    goto nothing;
   }
 
   g_print (_("server: connected to existing gxine instance.\n"));
   atexit (server_client_stop);
 
+  free (filename);
   return 1;
+
+nothing:
+  free (filename);
+  return 0;
 }
 
 int server_client_send (const char *cmd)
