@@ -56,6 +56,7 @@ gboolean wm_toolbar_visible = TRUE;
 gboolean wm_toolbar_snap = TRUE;
 
 gboolean fs_always_sticky = FALSE;
+gboolean fs_is_sticky = FALSE;
 
 GtkIconSize icon_size_logo;
 
@@ -207,8 +208,8 @@ static int check_remember_volume (const ui_adjustable_t *info)
 {
   xine_cfg_entry_t entry;
   return info->param != XINE_PARAM_AUDIO_VOLUME ||
-         !xine_config_lookup_entry (xine, "audio.volume.remember_volume", &entry) ||
-         entry.num_value;
+	 !xine_config_lookup_entry (xine, "audio.volume.remember_volume", &entry) ||
+	 entry.num_value;
 }
 
 static void ui_adjustment_value_changed_cb (GtkAdjustment *adj,
@@ -259,7 +260,7 @@ GtkObject *ui_register_control_adjustment (control_adjustment_t item)
     if (ranges[item].setting)
     {
       if (!check_remember_volume (&ranges[item]))
-        start = xine_get_param (stream, XINE_PARAM_AUDIO_VOLUME);
+	start = xine_get_param (stream, XINE_PARAM_AUDIO_VOLUME);
       else if (xine_config_lookup_entry (xine, ranges[item].setting, &entry))
 	start = entry.num_value;
     }
@@ -827,7 +828,7 @@ void ui_preferences_register (xine_t *this)
      _("In windowed mode, whether the logo is shown after playing an audio-only stream if no audio visualisation was active."), NULL,
      0, GXINE_TRUE, NULL);
 
-  fs_always_sticky = xine_config_register_bool
+  fs_is_sticky = fs_always_sticky = xine_config_register_bool
     (this, "gui.fullscreen_mode.always_sticky", 1,
      _("In full-screen mode, whether the video always appears on all desktops & viewports"),
      NULL, 0, NULL, NULL);
@@ -1122,10 +1123,10 @@ gboolean ui_post_init (void)
     {
     case CAP_VIDEO:
       if (ranges[i].cap && !(cap & ranges[i].cap))
-        ui_set_list (c_adj_widgets, i, "sensitive", 0);
+	ui_set_list (c_adj_widgets, i, "sensitive", 0);
       break;
     default:;
-    }      
+    }
 #endif
   }
   gdk_threads_leave ();
