@@ -350,9 +350,14 @@ static void response_cb (GtkWidget *dialog, gint response, gpointer data)
     gtk_widget_destroy (dialog);
 }
 
-void v_display_message (gxine_msg_source src, gboolean modal,
-			const gchar *primary, GtkMessageType type,
-			const gchar *fmt, va_list ap)
+static struct {
+  gchar *text;
+  GtkWidget *dbox;
+} combinable = { NULL, NULL };
+
+GtkWidget *v_display_message (gxine_msg_source src, gboolean modal,
+			      const gchar *primary, GtkMessageType type,
+			      const gchar *fmt, va_list ap)
 {
   static const char *const wtitle[][4] = {
     { N_("Message from gxine"),
@@ -365,8 +370,14 @@ void v_display_message (gxine_msg_source src, gboolean modal,
       N_("Question from the xine engine"),
       N_("Error from the xine engine"),
     },
+    { N_("Message from the xine engine"),
+      N_("Warning from the xine engine"),
+      N_("Question from the xine engine"),
+      N_("Error from the xine engine"),
+    },
   };
-  static const char *const ptitle[] = { "gxine", "xine-lib" };
+  static const char *const ptitle[] = { "gxine", "xine-lib", "xine-lib" };
+  static const uint8_t is_combinable[] = { FALSE, FALSE, TRUE };
 
   GtkWidget *dialog;
   gchar     *msg = g_strdup_vprintf (fmt, ap);
@@ -391,12 +402,42 @@ void v_display_message (gxine_msg_source src, gboolean modal,
 
   gdk_threads_enter ();
 
-  dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT |
+  if (is_combinable[src] && combinable.dbox)
+  {
+    dialog = combinable.dbox;
+
+    if (primary)
+    {
+      g_object_set (dialog, "message-type", type, "text", primary, NULL);
+      gchar *qmsg = g_markup_escape_text (msg, -1);
+      gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog),
+						"%s\n\n%s", qmsg, combinable.text);
+      free (qmsg);
+    }
+    else
+    {
+      g_object_set (dialog, "message-type", type, "text", msg, NULL);
+      gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog),
+						"%s", combinable.text);
+    }
+
+    gtk_window_set_focus_on_map (GTK_WINDOW (dialog), TRUE);
+    gtk_window_reshow_with_initial_size (GTK_WINDOW (dialog));
+  }
+  else
+  {
+    dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT |
 					   (modal ? GTK_DIALOG_MODAL : 0), type,
-				   GTK_BUTTONS_CLOSE, "%s", primary ? : msg);
-  if (primary)
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-					      "%s", msg);
+				     GTK_BUTTONS_CLOSE, "%s", primary ? : msg);
+    if (primary)
+      gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						"%s", msg);
+  }
+  /* lose the 'combinable' details regardless */
+  free (combinable.text);
+  combinable.text = NULL;
+  combinable.dbox = NULL;
+
   gtk_window_set_title (GTK_WINDOW (dialog), gettext (wtitle[src][type]));
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 
@@ -409,11 +450,13 @@ void v_display_message (gxine_msg_source src, gboolean modal,
   {
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
+    dialog = NULL;
   }
 
   gdk_threads_leave ();
-}
 
+  return dialog;
+}
 
 void display_error_modal (gxine_msg_source src, const gchar *title,
 			  const gchar *fmt, ...)
@@ -447,6 +490,57 @@ void display_info (gxine_msg_source src, const gchar *title,
   v_display_message (src, FALSE, title, GTK_MESSAGE_INFO, fmt, ap);
 }
 
+static void destroy_combinable (GtkWidget *dbox, gint which, gpointer data)
+{
+  if (dbox == combinable.dbox && data == combinable.text)
+  {
+    free (combinable.text);
+    combinable.text = NULL;
+    combinable.dbox = NULL;
+  }
+}
+
+static void __attribute__ ((format (printf, 4, 0)))
+v_display_combinable (gxine_msg_source src, const gchar *title,
+				  GtkMessageType type, const gchar *fmt,
+				  va_list ap)
+{
+  va_list apx;
+  gchar *msg;
+  va_copy (apx, ap);
+  vasprintf (&msg, fmt, ap);
+  msg = title ? g_markup_printf_escaped ("<b>%s</b>\n%s", title, msg)
+	      : strdup (msg);
+  combinable.dbox = v_display_message (src, FALSE, title, type, fmt, apx);
+  combinable.text = msg;
+  g_signal_connect (G_OBJECT (combinable.dbox), "response",
+		    G_CALLBACK (destroy_combinable), msg);
+}
+
+void display_error_combinable (gxine_msg_source src, const gchar *title,
+			       const gchar *fmt, ...)
+{
+  va_list ap;
+  va_start (ap, fmt);
+  v_display_combinable (src, title, GTK_MESSAGE_ERROR, fmt, ap);
+}
+
+void display_warning_combinable (gxine_msg_source src, const gchar *title,
+				 const gchar *fmt, ...)
+{
+  va_list ap;
+  va_start (ap, fmt);
+  v_display_combinable (src, title, GTK_MESSAGE_WARNING, fmt, ap);
+}
+
+void display_info_combinable (gxine_msg_source src, const gchar *title,
+			      const gchar *fmt, ...)
+{
+  va_list ap;
+  va_start (ap, fmt);
+  v_display_combinable (src, title, GTK_MESSAGE_INFO, fmt, ap);
+}
+
 void int_to_timestring (int int_time, char *string_time, gint length)
 {
   int sign = int_time < 0;
@@ -716,7 +810,7 @@ const char *const *gxine_list_video_output_plugins (xine_t *xine)
 #ifdef HAVE_XCB
   types |= 1 << XINE_VISUAL_TYPE_XCB;
 #endif
-  return xine_list_video_output_plugins_typed
+  return xine_check_version (1, 1, 12)
 	 ? xine_list_video_output_plugins_typed (xine, types)
 	 : xine_list_video_output_plugins (xine);
 }
